@@ -15,6 +15,7 @@ from ..dap_types import (
     ConfigurationDoneRequest,
     DisconnectArguments,
     DisconnectRequest,
+    Event,
     ExceptionBreakpointsFilter,
     InitializeRequestArguments,
     LaunchRequestArguments,
@@ -81,7 +82,7 @@ class LauncherDebugAdapterProtocol(DebugAdapterProtocol):
             supports_conditional_breakpoints=True,
             supports_hit_conditional_breakpoints=True,
             support_terminate_debuggee=True,
-            support_suspend_debuggee=True,
+            # support_suspend_debuggee=True,
             supports_evaluate_for_hovers=True,
             supports_terminate_request=True,
             supports_log_points=True,
@@ -125,6 +126,7 @@ class LauncherDebugAdapterProtocol(DebugAdapterProtocol):
         python: str,
         cwd: str = ".",
         target: Optional[str] = None,
+        paths: Optional[List[str]] = None,
         args: Optional[List[str]] = None,
         env: Optional[Dict[str, Optional[Any]]] = None,
         console: Optional[Literal["internalConsole", "integratedTerminal", "externalTerminal"]] = "integratedTerminal",
@@ -140,9 +142,10 @@ class LauncherDebugAdapterProtocol(DebugAdapterProtocol):
         outputLog: Optional[bool] = False,
         groupOutput: Optional[bool] = False,
         stopOnEntry: Optional[bool] = False,  # noqa: N803
-        arguments: Optional[LaunchRequestArguments] = None,
         dryRun: Optional[bool] = None,
         mode: Optional[str] = None,
+        variableFiles: Optional[List[str]] = None,
+        arguments: Optional[LaunchRequestArguments] = None,
         *_args: Any,
         **_kwargs: Any,
     ) -> None:
@@ -197,15 +200,26 @@ class LauncherDebugAdapterProtocol(DebugAdapterProtocol):
             for e in robotPythonPath:
                 run_args += ["-P", e]
 
+        if variableFiles:
+            for v in variableFiles:
+                run_args += ["-V", v]
+
         if variables:
             for k, v in variables.items():
                 run_args += ["-v", f"{k}:{v}"]
 
         run_args += args or []
 
+        if paths:
+            for p in paths:
+                run_args.append(p)
+
         if target:
             run_args.append(target)
 
+        if not paths and not target:
+            run_args.append(".")
+
         env = {k: ("" if v is None else str(v)) for k, v in env.items()} if env else {}
 
         if console in ["integratedTerminal", "externalTerminal"]:
@@ -263,6 +277,8 @@ class LauncherDebugAdapterProtocol(DebugAdapterProtocol):
     @rpc_method(name="terminate", param_type=TerminateArguments)
     async def _terminate(self, arguments: Optional[TerminateArguments] = None, *args: Any, **kwargs: Any) -> None:
         if self.client.connected:
+            self.send_event(Event("terminateRequested"))
+
             return await self.client.protocol.send_request_async(TerminateRequest(arguments=arguments))
         else:
             await self.send_event_async(TerminatedEvent())
