@@ -348,7 +348,7 @@ class RobotGotoProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixin):
         fixture_node = cast(Fixture, node)
 
         name_token = cast(Token, fixture_node.get_token(RobotToken.NAME))
-        if name_token is None or name_token.value is None or name_token.value in ("", "NONE"):
+        if name_token is None or name_token.value is None or name_token.value.upper() in ("", "NONE"):
             return None
 
         result = await self.get_keyworddoc_and_token_from_position(
@@ -421,7 +421,7 @@ class RobotGotoProtocolPart(RobotLanguageServerProtocolPart, ModelHelperMixin):
         if template_node.value:
 
             keyword_token = cast(RobotToken, template_node.get_token(RobotToken.NAME))
-            if keyword_token is None:
+            if keyword_token is None or keyword_token.value is None or keyword_token.value.upper() in ("", "NONE"):
                 return None
 
             keyword_token = self.strip_bdd_prefix(keyword_token)
